==> haskell-tasty-th-0.1.7-656-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-th
version:              0.1.7
visibility:           public
id:                   tasty-th-0.1.7-8WJLf3BwlQDHEuBIjnbKgL
key:                  tasty-th-0.1.7-8WJLf3BwlQDHEuBIjnbKgL
license:              BSD-3-Clause
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Oscar Finnsson & Emil Nordling & Benno Fünfstück
homepage:             http://github.com/bennofs/tasty-th
synopsis:             Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.

category:             Testing
abi:                  0aabc8546a43387d103bc4f924a7cf71
exposed:              True
exposed-modules:      Test.Tasty.TH
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-th-0.1.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-th-0.1.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-th
hs-libraries:         HStasty-th-0.1.7-8WJLf3BwlQDHEuBIjnbKgL
depends:
    base-4.18.2.1 haskell-src-exts-1.23.1-AH4Ip6Ctvxv6HZmnCjNeVF
    tasty-1.5.2-Bc3LD4OZ5taJ9AlqqiAeZ8 template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html:         /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-th-0.1.7-657-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-th
version:              0.1.7
visibility:           public
id:                   tasty-th-0.1.7-12Y6xRH1DaY5SYpYBk1wv7
key:                  tasty-th-0.1.7-12Y6xRH1DaY5SYpYBk1wv7
license:              BSD-3-Clause
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Oscar Finnsson & Emil Nordling & Benno Fünfstück
homepage:             http://github.com/bennofs/tasty-th
synopsis:             Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.

category:             Testing
abi:                  78923f5b2ce32c833cf12ce5fe431385
exposed:              True
exposed-modules:      Test.Tasty.TH
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-th-0.1.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-th-0.1.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-th
hs-libraries:         HStasty-th-0.1.7-12Y6xRH1DaY5SYpYBk1wv7
depends:
    base-4.18.2.1 haskell-src-exts-1.23.1-CUJaTf7lwGk2Fv2rDfVbix
    tasty-1.5.2-Bc3LD4OZ5taJ9AlqqiAeZ8 template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html:         /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
